Minigrad
==========

An autograd engine inspired by Karpathy's [micrograd](https://github.com/karpathy/micrograd) library. It is called mini because it is a little bit bigger than micrograd. Engine is implemented in Python C API so that Value type can be used in numpy functions. Currently nn.py and micrograd.nn are the same but will implement it in Numpy.

## Installation

``` bash
pip install minigrad
```

